﻿
using System;
using System.IO;
using Wisej.Web;

namespace WebBrowserTest
{
    public partial class Page1 : Page
    {
        private string DocRoot = String.Empty;

        public Page1()
        {
            InitializeComponent();
            DocRoot = Properties.Settings.Default.DocRoot;
            DirectoryInfo directoryInfo = new DirectoryInfo(DocRoot);

            BuildTree(directoryInfo, treeView1.Nodes);
            tabControl1.Dock = DockStyle.Fill;
            ckEditor1.Dock = DockStyle.Fill;
            //ckEditor1.SendToBack();
            ckEditor1.Visible = false;

            SetButtonsState(false);
            aspNetPanel1.PageSource = "http://localhost";
        }
        private void BuildTree(DirectoryInfo directoryInfo, TreeNodeCollection addInMe)
        {
            TreeNode curNode = addInMe.Add(directoryInfo.Name);
            foreach (FileInfo file in directoryInfo.GetFiles())
            {
                curNode.Nodes.Add(file.FullName, file.Name);
            }

            foreach (DirectoryInfo subdir in directoryInfo.GetDirectories())
            {
                BuildTree(subdir, curNode.Nodes);
            }
        }

        private void GetDirectories(DirectoryInfo[] subDirs, TreeNode nodeToAddTo)
        {
            TreeNode aNode;
            DirectoryInfo[] subSubDirs;
            foreach (DirectoryInfo subDir in subDirs)
            {
                aNode = new TreeNode(subDir.Name, 0, 0);
                aNode.Tag = subDir;
                subSubDirs = subDir.GetDirectories();
                if (subSubDirs.Length != 0)
                {
                    GetDirectories(subSubDirs, aNode);
                }

                nodeToAddTo.Nodes.Add(aNode);
            }
        }

        private void treeView1_AfterSelect(object sender, TreeViewEventArgs e)
        {
            RefreshGUI(e.Node.Name);
        }

        private void toolBar1_ButtonClick(object sender, ToolBarButtonClickEventArgs e)
        {
            switch (e.Button.Name)
            {
               case "tlbBtn_Edit":
                    SetButtonsState(true);

                    ckEditor1.Visible = true;
                    //ckEditor1.BringToFront();
                    ckEditor1.Text = System.IO.File.ReadAllText(treeView1.SelectedNode.Name);
                    //ckEditor1.Invalidate();
                    //ckEditor1.PerformLayout();
                    //ckEditor1.Refresh();
                    //ckEditor1.Update();

                    break;

                case "tlbBtn_Save":
                    SetButtonsState(false);

                    System.IO.File.WriteAllText(System.IO.Path.Combine(DocRoot, treeView1.SelectedNode.Name), ckEditor1.Text);
                    ckEditor1.Visible = false;
                    //ckEditor1.SendToBack();
                    RefreshGUI(treeView1.SelectedNode.Name);
                    break;

                case "tlbBtn_Cancel":
                    SetButtonsState(false);

                    ckEditor1.Visible = false;
                    //ckEditor1.SendToBack();

                    RefreshGUI(treeView1.SelectedNode.Name);
                    break;
            }
        }

        private void SetButtonsState(bool isEditing)
        {
            if (isEditing == true)
            {
                tlbBtn_Edit.Enabled = false;
                tlbBtn_Save.Enabled = true;
                tlbBtn_Cancel.Enabled = true;
            }
            else
            {
                tlbBtn_Edit.Enabled = true;
                tlbBtn_Save.Enabled = false;
                tlbBtn_Cancel.Enabled = false;
            }
        }

        private void RefreshGUI(string FullFileName)
        {
            htmlPanel1.HtmlSource = FullFileName;
            htmlPanel1.Refresh(true);
            htmlPanel1.Update();

            iFramePanel1.Url = Properties.Settings.Default.HTTPRoot + System.IO.Path.GetFileName(FullFileName) + "?v=1";
            //iFramePanel1.Invalidate(true);
            //iFramePanel1.Refresh(true);
            iFramePanel1.Update();

            webBrowser1.Url = new Uri(Properties.Settings.Default.HTTPRoot + System.IO.Path.GetFileName(FullFileName) + "?v=1");
            //webBrowser1.Invalidate(true);
            //webBrowser1.Refresh(true);
            webBrowser1.Update();

            aspNetPanel1.PageSource = Properties.Settings.Default.HTTPRoot + System.IO.Path.GetFileName(FullFileName) + "?v=1";

            //tabControl1.Invalidate(true);
            //tabControl1.Refresh(true);
            tabControl1.Update();
        }
    }
}
